@@ -76,8 +76,8 @@ static bild_besch_t* create_textured_tile(const bild_besch_t* bild_lightmap, con
 	sint16        const x_y     = bild_texture->get_pic()->w;
 	// now mix the images
 	for (int j = 0; j < bild_dest->get_pic()->h; j++) {
-		sint16 x = *dest++;
-		const sint16 offset = (bild_dest->get_pic()->y + j - bild_texture->get_pic()->y) * (x_y + 3) + 2; // position of the pixel in a rectangular map
+		sint32 x = *dest++;
+		const sint32 offset = (bild_dest->get_pic()->y + j - bild_texture->get_pic()->y) * (x_y + 3) + 2; // position of the pixel in a rectangular map
 		do
 		{
 			sint16 runlen = *dest++;
@@ -1019,8 +1019,8 @@ void grund_besch_t::init_ground_textures(karte_t *w)
  */
 image_id grund_besch_t::get_ground_tile(grund_t *gr)
 {
-	hang_t::typ slope = gr->get_disp_slope();
-	sint16 height = gr->get_disp_height();
+	hang_t::typ slope = gr->get_grund_hang();
+	sint16 height = gr->get_hoehe();
 	koord k = gr->get_pos().get_2d();
 	const sint16 tile_h = height - welt->get_water_hgt(k);
 	if(  tile_h < 0  ||  (tile_h == 0  &&  slope == hang_t::flach)  ) {
