@@ -796,6 +796,11 @@ void map_frame_t::draw(scr_coord pos, scr_size size)
 			display_proportional(xpos + D_INDICATOR_BOX_WIDTH + 2, ypos, i.text.c_str(), ALIGN_LEFT, SYSCOL_TEXT, false);
 		}
 	}
+
+	// may add compass
+	if(  skinverwaltung_t::compass_map  &&  env_t::compass_map_position!=0  ) {
+		display_img_aligned( skinverwaltung_t::compass_map->get_bild_nr( welt->get_settings().get_rotation()+reliefkarte_t::get_karte()->isometric*4 ), scrolly.get_client()+pos+scr_coord(4,4+D_TITLEBAR_HEIGHT)-scr_size(8,8), env_t::compass_map_position, false );
+	}
 }
 
 
