@@ -400,9 +400,10 @@ void welt_gui_t::update_densities()
  * Calculate the new Map-Preview. Initialize the new RNG!
  * @author Hj. Malthaner
  */
-void welt_gui_t::update_preview()
+void welt_gui_t::update_preview(bool load_heightfield)
 {
-	if(  loaded_heightfield  ) {
+	if(  loaded_heightfield  ||  load_heightfield) {
+		loaded_heightfield = true;
 		update_from_heightfield(sets->heightfield.c_str());
 	}
 	else {
@@ -507,7 +508,8 @@ bool welt_gui_t::action_triggered( gui_action_creator_t *komp,value_t v)
 		loaded_heightfield = false;
 		sets->heightfield = "";
 		sets->grundwasser = -2;
-		create_win(new load_relief_frame_t(sets), w_info, magic_load_t);
+		load_relief_frame_t* lrf = new load_relief_frame_t(sets);
+		create_win((display_get_width() - lrf->get_windowsize().w-10), 40, lrf, w_info, magic_load_t );
 		knr = sets->get_karte_nummer();	// otherwise using cancel would not show the normal generated map again
 	}
 	else if(komp==&use_intro_dates) {
