@@ -116,7 +116,8 @@ private:
 	/// clears statistics, transit, and weighted_sum_storage
 	void init_stats();
 public:
-	ware_production_t() : type(NULL), menge(0), max(0)/*, transit(statistics[0][FAB_GOODS_TRANSIT])*/, max_transit(0), index_offset(0)
+	ware_production_t() : type(NULL), menge(0), max(0)/*, transit(statistics[0][FAB_GOODS_TRANSIT])*/,
+	                      max_transit(0), placing_orders(false), index_offset(0)
 	{
 #ifdef TRANSIT_DISTANCE
 		count_suppliers = 0;
