@@ -31,7 +31,7 @@
 #include "simloadingscreen.h"
 #include "simticker.h"
 #include "simmesg.h"
-#include "simtool.h"
+#include "simmenu.h"
 #include "siminteraction.h"
 
 #include "simsys.h"
@@ -1056,9 +1056,11 @@ int simu_main(int argc, char** argv)
 		}
 	}
 
+	bool old_restore_UI = env_t::restore_UI;
 	if(  new_world  &&  env_t::reload_and_save_on_quit  ) {
 		// construct from pak name an autosave if requested
 		loadsave_t file;
+
 		std::string pak_name( "autosave-" );
 		pak_name.append( env_t::objfilename );
 		pak_name.erase( pak_name.length()-1 );
@@ -1068,6 +1070,7 @@ int simu_main(int argc, char** argv)
 		rename( pak_name.c_str(), "temp-load.sve" );
 		loadgame = "temp-load.sve";
 		new_world = false;
+		env_t::restore_UI = true;
 	}
 
 	// still nothing to be loaded => search for demo games
@@ -1171,6 +1174,7 @@ DBG_MESSAGE("simmain","loadgame file found at %s",buffer);
 	setsimrand(dr_time(), dr_time());
 	clear_random_mode( 7 );	// allow all
 
+
 	if(  loadgame==""  ||  !welt->load(loadgame.c_str())  ) {
 		// create a default map
 		DBG_MESSAGE("init with default map","(failing will be a pak error!)");
@@ -1263,7 +1267,11 @@ DBG_MESSAGE("simmain","loadgame file found at %s",buffer);
 	// the real fonts for the current language
 	sprachengui_t::init_font_from_lang();
 
-	destroy_all_win(true);
+	if(   !(env_t::reload_and_save_on_quit  &&  !new_world)  ) {
+		destroy_all_win(true);
+	}
+	env_t::restore_UI = old_restore_UI;
+
 	if(  !env_t::networkmode  &&  !env_t::server  &&  new_world  ) {
 		welt->get_message()->clear();
 	}
