@@ -141,8 +141,14 @@ int dr_os_open(int const w, int const h, int fullscreen)
 		settings.dmDisplayFrequency = 0;
 
 		if(  ChangeDisplaySettings(&settings, CDS_TEST)!=DISP_CHANGE_SUCCESSFUL  ) {
-			ChangeDisplaySettings( NULL, 0 );
+			// evt. try again in 32 bit
+			if(  COLOUR_DEPTH<32  ) {
+				settings.dmBitsPerPel = 32;
+			}
 			printf( "dr_os_open()::Could not reduce color depth to 16 Bit in fullscreen." );
+		}
+		if(  ChangeDisplaySettings(&settings, CDS_TEST)!=DISP_CHANGE_SUCCESSFUL  ) {
+			ChangeDisplaySettings( NULL, 0 );
 			fullscreen = false;
 		}
 		else {
