@@ -378,7 +378,7 @@ private:
 	static char toolstring[256];
 	const char *tool_station_building_aux(player_t *, bool, koord3d, const haus_besch_t *, sint8 rotation );
 	const char *tool_station_dock_aux(player_t *, koord3d, const haus_besch_t * );
-	const char *tool_station_flat_dock_aux(player_t *, koord3d, const haus_besch_t * );
+	const char *tool_station_flat_dock_aux(player_t *, koord3d, const haus_besch_t *, sint8 );
 	const char *tool_station_aux(player_t *, koord3d, const haus_besch_t *, waytype_t, const char *halt_suffix );
 	const haus_besch_t *get_besch( sint8 &rotation ) const;
 
@@ -845,6 +845,7 @@ class tool_rotate90_t : public tool_t {
 public:
 	tool_rotate90_t() : tool_t(TOOL_ROTATE90 | SIMPLE_TOOL) {}
 	image_id get_icon(player_t*) const OVERRIDE { return env_t::networkmode ? IMG_LEER : icon; }
+	virtual void draw_after(scr_coord pos, bool dirty) const; /* may draw a compass on top */
 	char const* get_tooltip(player_t const*) const OVERRIDE { return env_t::networkmode ? translator::translate("deactivated in online mode") : translator::translate("Rotate map"); }
 	bool init( player_t * ) OVERRIDE;
 	bool is_init_network_save() const OVERRIDE { return !env_t::networkmode; }
